/*

    File: testdisk.c

    Copyright (C) 1998-2000  Christophe Grenier <grenier@nef.esiea.fr>
  
    This software is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.
  
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
  
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

 */

#include <curses.h>
#include <time.h>
#include <sys/time.h>
#include <sys/types.h>
#include <ctype.h>      /* toupper, tolower */
#include "types.h"
#include "common.h"
#include "testdisk.h"
#include "lang.h"
#include "interface.h"

FILE *f_rapport=NULL;

int ecrit_rapport(const char *_format, ...)
{
  if(f_rapport)
    return vfprintf(f_rapport,_format,(&_format)+1);
  return 0;
}

int doprintf(const char *_format, ...)
{
  char res[800];
#ifdef DEBUG
  if(f_rapport)
    vfprintf(f_rapport,_format,(&_format)+1);
#endif
#ifdef DJGPP
  vsprintf(res,_format,(&_format)+1);
#else
  vsnprintf(res,sizeof(res),_format,(&_format)+1);
#endif
  return addstr(res);
}

int ask_YN(const char* msg)
{
  char res;
  doprintf(msg);
  refresh();
  do
  {
    res=toupper(getch());
  } while((res!=c_NO)&(res!=c_YES));
  doprintf("%c\n",res);
  return (res==c_YES);
}

FILE* init_log(const char*filename,int argc, char**argv)
{
  FILE*f_file=fopen(filename,"a");
  if(f_file==NULL)
	printf(m_LOG_ERR);
  else
  {
	int i;
	time_t my_time=time(NULL);
	fprintf(f_file,m_CMDLINE);
	for(i=1;i<argc;i++)
	  fprintf(f_file," %s", argv[i]);
	fprintf(f_file,"\n%s",ctime(&my_time));
  }
  return f_file;
}

int main( int argc, char **argv )
{
  int i;
  unsigned int x;
  int help=0, create_log=0,paranoid=0,debug=0, dump_ind=0;
  int fast_mode=1;
  for(i=1;i<argc;i++)
  {
    for (x=0; x < strlen( argv[i] ); x++)
     argv[i][x] = tolower( argv[i][x] );
    if (!strcmp(argv[i],"/trust")) ;
    else if (!strcmp(argv[i],"/liar")) ;
    else if (!strcmp(argv[i],"/trust_auto")) ;
    else if (!strcmp(argv[i],"/search"));
    else if (!strcmp(argv[i],"/fast"))
      fast_mode=1;
    else if (!strcmp(argv[i],"/slow"))
      fast_mode=0;
    else if(!strcmp(argv[i],"/log"))
      create_log=1;
    else if(!strcmp(argv[i],"/mbr"));
    else if(!strcmp(argv[i],"/clean"));
    else if(!strcmp(argv[i],"/paranoid"))
      paranoid=1;
    else if(!strcmp(argv[i],"/debug"))
	{
      debug=1;
	  create_log=1;
	}
	else if(!strcmp(argv[i],"/dump"))
	  dump_ind=1;
	else if(!strcmp(argv[i],"/geometry"));
    else
      help=1;
  }
  if(help)
  {
    printf(m_Copyright);
	printf(m_Usage);
    return 0;
  }
#ifndef DJGPP
  if(geteuid()!=0)
  {
	printf("You need to be root to use TestDisk\n");
	return 1;
  }
#endif
  if(create_log)
    f_rapport=init_log("testdisk.log",argc,argv);
  do_curses_testdisk(debug,paranoid,dump_ind,fast_mode);
#ifndef DJGPP
  printf("\n");
#endif
  if(f_rapport)
	fclose(f_rapport);
  return 0;
}
